]> the.earth.li Git - onak.git/blobdiff - keydb.h
Configure basic onak.conf using autoconf info.
[onak.git] / keydb.h
diff --git a/keydb.h b/keydb.h
index b356bb85380340b6d0f6f06aaa609c59587a0241..ae87ce385c561b2811d8324922d03aa86735cdf5 100644 (file)
--- a/keydb.h
+++ b/keydb.h
@@ -4,8 +4,6 @@
  * Jonathan McDowell <noodles@earth.li>
  *
  * Copyright 2002 Project Purple
- *
- * $Id: keydb.h,v 1.8 2003/06/07 13:45:34 noodles Exp $
  */
 
 #ifndef __KEYDB_H__
 
 /**
  *     initdb - Initialize the key database.
+ *     @readonly: If we'll only be reading the DB, not writing to it.
  *
  *     This function should be called before any of the other functions in
  *     this file are called in order to allow the DB to be initialized ready
  *     for access.
  */
-void initdb(void);
+void initdb(bool readonly);
 
 /**
  *     cleanupdb - De-initialize the key database.
@@ -110,11 +109,13 @@ char *keyid2uid(uint64_t keyid);
 /**
  *     getkeysigs - Gets a linked list of the signatures on a key.
  *     @keyid: The keyid to get the sigs for.
+ *     @revoked: Is the key revoked?
  *
  *     This function gets the list of signatures on a key. Used for key 
*     indexing and doing stats bits.
  */
-struct ll *getkeysigs(uint64_t keyid);
+struct ll *getkeysigs(uint64_t keyid, bool *revoked);
 
 /**
  *     cached_getkeysigs - Gets the signatures on a key.
@@ -110,11 +109,13 @@ char *keyid2uid(uint64_t keyid);
  *
  *     This function gets the list of signatures on a key. Used for key 
- *     indexing and doing stats bits.
+ *     indexing and doing stats bits. If revoked is non-NULL then if the key
+ *     is revoked it's set to true.
  */